﻿namespace BPA.MES.Base.Application.Services
{
    /// <summary>
    /// 名    称 ：AGV点位管理  
    /// 创 建 人 ：yangxiao  
    /// 创建时间 ：  2023/8/7 10:03:37 
    /// 描    述 ：  
    /// </summary>
    [ApiDescriptionSettings("AGV管理", Name = "AgvPoint", Tag = "AGV点位", KeepName = true, SplitCamelCase = true, KeepVerb = true)]
    public class AgvPointService : IAgvPointService, ITransient, IDynamicApiController
    {
        private readonly ISqlSugarClient _dbContext;
        public AgvPointService(ISqlSugarClient db)
        {
            _dbContext = db;
        }
        /// <summary>
        /// 增加
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        [HttpPost]
        public async Task<bool> Add(AgvPointAddInput input)
        {
            var r_entity = await _dbContext.Queryable<AgvPointEntity>().FirstAsync(x => x.Name == input.Name);
            if (r_entity != null)
            {
                throw Oops.Bah("名称已存在!");
            }
            AgvPointEntity entity = input.Adapt<AgvPointEntity>();
            return await _dbContext.Insertable(entity).IgnoreColumns(ignoreNullColumn: true).ExecuteCommandIdentityIntoEntityAsync();
        }
        /// <summary>
        /// 删除
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpPost]
        public async Task<bool> Del(AgvPointDelInput input)
        {
            var res = await _dbContext.Deleteable<AgvPointEntity>().Where(x => x.Id == input.Id).ExecuteCommandHasChangeAsync();
            return res;
        }
        /// <summary>
        /// 详情
        /// </summary>
        /// <param name="Id"></param>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpGet]
        public async Task<AgvPointOutput> Detail(string Id)
        {
            var entity = await _dbContext.Queryable<AgvPointEntity>().FirstAsync(x => x.Id == Id);
            AgvPointOutput output = entity.Adapt<AgvPointOutput>();
            return output;
        }
        /// <summary>
        /// 列表
        /// </summary>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpPost]
        public async Task<List<AgvPointOutput>> List(AgvPointQueryInput input)
        {
            var entity = await _dbContext.Queryable<AgvPointEntity>().ToListAsync();
            List<AgvPointOutput> output = entity.Adapt<List<AgvPointOutput>>();
            return output;
        }
        /// <summary>
        /// 分页
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        [HttpPost]
        public async Task<SqlSugarPagedList<AgvPointOutput>> PagedList(AgvPointQueryPageInput input)
        {
            var entity = await _dbContext.Queryable<AgvPointEntity>()
                .WhereIF(!string.IsNullOrEmpty(input.Name), x => x.Name.Contains(input.Name))
                .WhereIF(!string.IsNullOrEmpty(input.Code), x => x.Code.Contains(input.Code))
                .ToPagedListAsync(input.PageIndex, input.PageSize);
            SqlSugarPagedList<AgvPointOutput> output = entity.Adapt<SqlSugarPagedList<AgvPointOutput>>();
            return output;
        }
        /// <summary>
        /// 下拉
        /// </summary>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpGet]
        public async Task<dynamic> SelectList()
        {
            var entity = await _dbContext.Queryable<AgvPointEntity>().Select(x => new
            {
                key = x.Id,
                value = x.Name
            }).ToListAsync();
            return entity;
        }
        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpPost]
        public async Task<bool> Update(AgvPointUpdateInput input)
        {
            var entity = await _dbContext.Queryable<AgvPointEntity>().Where(x => x.Id == input.Id).FirstAsync();
            entity = input.Adapt<AgvPointEntity>();
            var res = await _dbContext.Updateable(entity).IgnoreColumns(true).ExecuteCommandHasChangeAsync();
            return res;
        }
    }
}