﻿namespace BPA.MES.Base.Application.Services
{
    /// <summary>
    /// 名    称 ：设备参数  
    /// 创 建 人 ：yangxiao  
    /// 创建时间 ：  2023/7/31 18:03:25 
    /// 描    述 ：  
    /// </summary>
    [ApiDescriptionSettings("设备产品模型", Name = "DeviceProductParm", Tag = "设备产品参数", KeepName = true, SplitCamelCase = true, KeepVerb = true)]
    public class DeviceProductParmService : IDeviceProductParmService, ITransient, IDynamicApiController
    {
        private readonly ISqlSugarClient _dbContext;
        public DeviceProductParmService(ISqlSugarClient db)
        {
            _dbContext = db;
        }
        /// <summary>
        /// 增加
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        [HttpPost]
        public async Task<bool> Add(DeviceProductParmAddInput input)
        {
            var r_entity = await _dbContext.Queryable<DeviceProductParmEntity>().FirstAsync(x => x.Code == input.Name);
            if (r_entity != null)
            {
                throw Oops.Bah("名称已存在!");
            }
            DeviceProductParmEntity entity = input.Adapt<DeviceProductParmEntity>();
            return await _dbContext.Insertable(entity).IgnoreColumns(ignoreNullColumn: true).ExecuteCommandIdentityIntoEntityAsync();
        }
        /// <summary>
        /// 删除
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpPost]
        public async Task<bool> Del(DeviceProductParmDelInput input)
        {
            var res = await _dbContext.Deleteable<DeviceProductParmEntity>().Where(x => x.Id == input.Id).ExecuteCommandHasChangeAsync();
            return res;
        }
        /// <summary>
        /// 详情
        /// </summary>
        /// <param name="Id"></param>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpGet]
        public async Task<DeviceProductParmOutput> Detail(string Id)
        {
            var entity = await _dbContext.Queryable<DeviceProductParmEntity>().FirstAsync(x => x.Id == Id);
            DeviceProductParmOutput output = entity.Adapt<DeviceProductParmOutput>();
            return output;
        }
        /// <summary>
        /// 列表
        /// </summary>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpPost]
        public async Task<List<DeviceProductParmOutput>> List(DeviceProductParmQueryInput input)
        {
            var entity = await _dbContext.Queryable<DeviceProductParmEntity>().ToListAsync();
            List<DeviceProductParmOutput> output = entity.Adapt<List<DeviceProductParmOutput>>();
            return output;
        }
        /// <summary>
        /// 分页
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        [HttpPost]
        public async Task<SqlSugarPagedList<DeviceProductParmOutput>> PagedList(DeviceProductParmQueryPageInput input)
        {
            var entity = await _dbContext.Queryable<DeviceProductParmEntity>()
                .WhereIF(!string.IsNullOrEmpty(input.Code), x => x.Code.Contains(input.Code))
                .ToPagedListAsync(input.PageIndex, input.PageSize);
            SqlSugarPagedList<DeviceProductParmOutput> output = entity.Adapt<SqlSugarPagedList<DeviceProductParmOutput>>();
            return output;
        }
        /// <summary>
        /// 下拉
        /// </summary>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpGet]
        public async Task<dynamic> SelectList()
        {
            var entity = await _dbContext.Queryable<DeviceProductParmEntity>().Select(x => new
            {
                key = x.Id,
                value = x.Code
            }).ToListAsync();
            return entity;
        }
        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        [HttpPost]
        public async Task<bool> Update(DeviceProductParmUpdateInput input)
        {
            var entity = await _dbContext.Queryable<DeviceProductParmEntity>().Where(x => x.Id == input.Id).FirstAsync();
            entity = input.Adapt<DeviceProductParmEntity>();
            var res = await _dbContext.Updateable(entity).IgnoreColumns(true).ExecuteCommandHasChangeAsync();
            return res;
        }
    }
}
